<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class WooCommerce_Shipmate_Order_Metabox {
	protected $PROPERTY;

	public function __construct($PROPERTY)
	{
		$this->PROPERTY = $PROPERTY;
	}




	/**
	 * Output the metabox.
	 *
	 * @param WP_Post $post
	 */
	public static function output( $post ) {



		$order_id = $post->ID;

		$status = $post->post_status;
		
		// get details
		$created_with_shipmate = get_post_meta( $order_id, "_wc_order_printed_with_shipmate", true ) == 'yes';

		

		// If the shipmate_sender_name is Naturaw
		if(get_option('shipmate_sender_name', true) == "Naturaw") {

			// total order weight
			$wooOrder = new WC_Order($order_id);
			$weight = 0;
			if (sizeof($wooOrder->get_items()) > 0 ) {
				$items = $wooOrder->get_items();
				foreach($items as $item) {
					if ($item['product_id'] > 0) {
						$product = $wooOrder->get_product_from_item($item);
						if (!$product->is_virtual()) {
							$weight += $product->get_weight() * $item['qty'];
						}
					}
				}
			}

			// Get weight unit and convert based on that
			switch(get_option('woocommerce_weight_unit')) {
				case 'g':
					$start_count = ceil(($weight / 1000) / 15.5);
					break;
				case 'kg':
					$start_count = ceil($weight / 15.5);
					break;
				case 'lbs':
					$start_count = ceil(($weight / 2.205) / 15.5);
					break;
				case 'oz':
					$start_count = ceil(($weight / 35.274) / 15.5);
					break;
			}		
		} else {
			$start_count = 1;
		}



		// get the servide and carrier used
		$shipmate_carrier = get_post_meta( $order_id, '_shipmate_carrier', true);
		$shipmate_service = get_post_meta( $order_id, '_shipmate_service', true);
		$tracking_events = array();

		$shipmate_api_service = new WooCommerce_Shipmate_Service();

		if($created_with_shipmate) {
			$response = $shipmate_api_service->tracking_events($order_id);
			if($response->http_code() == 200) {
				$tracking_events = $response->data();
			} else {
				$tracking_events = array();
			}
		}
		$shipmate_services = array();

		if(!$created_with_shipmate) {
			$response = $shipmate_api_service->services();

			if($response->http_code() == 200) {
				$shipmate_services = $response->data();
			}
		}


		$packaging_options = array();
		if(!$created_with_shipmate) {
			$response = $shipmate_api_service->packaging_option();

			if($response->http_code() == 200) {
				$packaging_options = $response->data();
			}
		}


		// get parcel dimensions and tracking
		$parcels = array();

		if($created_with_shipmate) {
			$parcel_references = get_post_meta($order_id, '_shipmate_parcel_reference', false);
	    	$tracking_references = get_post_meta($order_id, '_shipmate_tracking_reference', false);
	    	$parcel_weights = get_post_meta($order_id, '_shipmate_parcel_weight', false);
	    	$parcel_lengths = get_post_meta($order_id, '_shipmate_parcel_length', false);
	    	$parcel_widths = get_post_meta($order_id, '_shipmate_parcel_width', false);
	    	$parcel_depths = get_post_meta($order_id, '_shipmate_parcel_depth', false);

	    	foreach($parcel_references as $key => $parcel_reference) {
	    		
	    		$tracking_reference = $tracking_references[$key];
	    		
	    		$parcel_events = !empty($tracking_events->{$tracking_reference}) ? $tracking_events->{$tracking_reference} : array();
	    		$recent_event = null;
	    		
	    		if(!empty($parcel_events)) {
	    		
	    				$recent_event = $parcel_events->tracking_events[count($parcel_events->tracking_events) - 1];
	    				
	    		}

	    		$parcels[] = array(
	    			'sender_reference' 		=> $parcel_references[$key],
	    			'tracking_reference' 	=> $tracking_references[$key],
	    			'weight' 				=> $parcel_weights[$key],
	    			'length' 				=> $parcel_lengths[$key],
	    			'width' 				=> $parcel_widths[$key],
	    			'depth' 				=> $parcel_depths[$key],
	    			'recent_event'			=> $recent_event
	    		);
	    	}
		}
		include_once( dirname( __FILE__ ) . '/views/html-admin-order-shipmate.php' );
	}

	/**
	 * Save meta box data.
	 *
	 * @param int $post_id
	 * @param WP_Post $post
	 */
	public static function save( $post_id, $post ) {
	
	}
}
